summaryrefslogtreecommitdiffstats
path: root/src/mbedTLS++/CtrDrbgContext.h
diff options
context:
space:
mode:
authorpeterbell10 <peterbell10@live.co.uk>2017-08-30 16:00:06 +0200
committerTiger Wang <ziwei.tiger@outlook.com>2017-08-30 16:00:06 +0200
commit84941bcc9f25cbe3fd3b2604080d0a1cfd8fbaa7 (patch)
treeaa1648c2ba260b8576673677435481d371eec7b0 /src/mbedTLS++/CtrDrbgContext.h
parentUpdate core plugins to latest version (#3951) (diff)
downloadcuberite-84941bcc9f25cbe3fd3b2604080d0a1cfd8fbaa7.tar
cuberite-84941bcc9f25cbe3fd3b2604080d0a1cfd8fbaa7.tar.gz
cuberite-84941bcc9f25cbe3fd3b2604080d0a1cfd8fbaa7.tar.bz2
cuberite-84941bcc9f25cbe3fd3b2604080d0a1cfd8fbaa7.tar.lz
cuberite-84941bcc9f25cbe3fd3b2604080d0a1cfd8fbaa7.tar.xz
cuberite-84941bcc9f25cbe3fd3b2604080d0a1cfd8fbaa7.tar.zst
cuberite-84941bcc9f25cbe3fd3b2604080d0a1cfd8fbaa7.zip
Diffstat (limited to '')
-rw-r--r--src/mbedTLS++/CtrDrbgContext.h (renamed from src/PolarSSL++/CtrDrbgContext.h)16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/PolarSSL++/CtrDrbgContext.h b/src/mbedTLS++/CtrDrbgContext.h
index 20d687015..21d786c2e 100644
--- a/src/PolarSSL++/CtrDrbgContext.h
+++ b/src/mbedTLS++/CtrDrbgContext.h
@@ -1,7 +1,7 @@
-
+
// CtrDrbgContext.h
// Declares the cCtrDrbgContext class representing a wrapper over CTR-DRBG implementation in PolarSSL
@@ -9,7 +9,7 @@
#pragma once
-#include "polarssl/ctr_drbg.h"
+#include "mbedtls/ctr_drbg.h"
@@ -24,7 +24,7 @@ class cEntropyContext;
class cCtrDrbgContext
{
- friend class cSslContext;
+ friend class cSslConfig;
friend class cRsaPrivateKey;
friend class cCryptoKey;
@@ -37,7 +37,7 @@ public:
/** Initializes the context.
a_Custom is optional additional data to use for entropy, nullptr is accepted.
- Returns 0 if successful, PolarSSL error code on failure. */
+ Returns 0 if successful, mbedTLS error code on failure. */
int Initialize(const void * a_Custom, size_t a_CustomSize);
/** Returns true if the object is valid (has been initialized properly) */
@@ -48,14 +48,14 @@ protected:
std::shared_ptr<cEntropyContext> m_EntropyContext;
/** The random generator context */
- ctr_drbg_context m_CtrDrbg;
+ mbedtls_ctr_drbg_context m_CtrDrbg;
/** Set to true if the object is valid (has been initialized properly) */
bool m_IsValid;
- /** Returns the internal context ptr. Only use in PolarSSL API calls. */
- ctr_drbg_context * GetInternal(void) { return &m_CtrDrbg; }
+ /** Returns the internal context ptr. Only use in mbedTLS API calls. */
+ mbedtls_ctr_drbg_context * GetInternal(void) { return &m_CtrDrbg; }
} ;
@@ -1,7 +1,7 @@
// CtrDrbgContext.h
-// Declares the cCtrDrbgContext class representing a wrapper over CTR-DRBG implementation in PolarSSL
+// Declares the cCtrDrbgContext class representing a wrapper over CTR-DRBG implementation in mbedTLS
#pragma once